@@ -18,14 +18,14 @@ function receiveSmifDetails(json) {
 
 export function fetchSmifDetails(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSmifDetails())
 
         // make API request, returning a promise
         return fetch('/api/v1/smif/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSmifDetails(json))
@@ -49,20 +49,30 @@ function receiveSosModelRuns(json) {
     }
 }
 
-export function fetchSosModelRuns(){
+export function fetchSosModelRuns(filter = undefined){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSosModelRuns())
 
         // make API request, returning a promise
-        return fetch('/api/v1/sos_model_runs/')
-            .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                json => dispatch(receiveSosModelRuns(json))
-            )
+        if (filter == undefined) {
+            return fetch('/api/v1/sos_model_runs/')
+                .then(
+                    response => response.json()
+                )
+                .then(
+                    json => dispatch(receiveSosModelRuns(json))
+                )
+        } else {
+            return fetch('/api/v1/sos_model_runs/?' + filter)
+                .then(
+                    response => response.json()
+                )
+                .then(
+                    json => dispatch(receiveSosModelRuns(json))
+                )
+        }
     }
 }
 
@@ -84,14 +94,14 @@ function receiveSosModelRun(json) {
 
 export function fetchSosModelRun(modelrunid){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSosModelRun())
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_model_runs/' + modelrunid)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSosModelRun(json))
@@ -99,9 +109,41 @@ export function fetchSosModelRun(modelrunid){
     }
 }
 
-export function saveSosModelRun(modelrun){
+export const REQUEST_SOS_MODEL_RUN_STATUS = 'REQUEST_SOS_MODEL_RUN_STATUS'
+function requestSosModelRunStatus(){
+    return {
+        type: REQUEST_SOS_MODEL_RUN_STATUS
+    }
+}
+
+export const RECEIVE_SOS_MODEL_RUN_STATUS = 'RECEIVE_SOS_MODEL_RUN_STATUS'
+function receiveSosModelRunStatus(json) {
+    return {
+        type: RECEIVE_SOS_MODEL_RUN_STATUS,
+        sos_model_run_status: json,
+        receivedAt: Date.now()
+    }
+}
+
+export function fetchSosModelRunStatus(modelrunid){
     return function (dispatch) {
+
         // inform the app that the API request is starting
+        dispatch(requestSosModelRunStatus())
+
+        // make API request, returning a promise
+        return fetch('/api/v1/sos_model_runs/' + modelrunid + '/status')
+            .then(
+                response => response.json()
+            )
+            .then(
+                json => dispatch(receiveSosModelRunStatus(json))
+            )
+    }
+}
+
+export function saveSosModelRun(modelrun){
+    return function () {
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_model_runs/' + modelrun.name, {
@@ -113,46 +155,28 @@ export function saveSosModelRun(modelrun){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                //json => dispatch(receiveSosModelRun(json))
+                response => response.json()
             )
     }
 }
 
-export function createSosModelRun(sosModelRunName){
+export function createSosModelRun(sosModelRun){
     return function (dispatch) {
-        // prepare the new modelrun
-        let datetime = new Date()
-
-        let newModelRun = {
-            'name': sosModelRunName,
-            'description': '',
-            'stamp': datetime.toISOString(),
-            'sos_model': '',
-            'scenarios': {},
-            'narratives': {},
-            'decision_module': '',
-            'timesteps': [2015, 2020]
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_model_runs/', {
             method: 'post',
-            body: JSON.stringify(newModelRun),
+            body: JSON.stringify(sosModelRun),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-            //json => dispatch(receiveSosModelRun(json))
+                function() {
+                    response => response.json()
+                    dispatch(fetchSosModelRuns())
+                }
             )
     }
 }
@@ -169,8 +193,47 @@ export function deleteSosModelRun(sosModelRunName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchSosModelRuns())
+                }
+            )
+    }
+}
+
+export function startSosModelRun(sosModelRunName, args){
+    return function () {
+
+        // make API request, returning a promise
+        return fetch('/api/v1/sos_model_runs/' + sosModelRunName + '/start', {
+            method: 'post',
+            body: JSON.stringify({
+                args: args
+            }),
+
+            headers: {
+                'Content-Type': 'application/json'
+            }
+        })
+            .then(
+                response => response.json()
+            )
+    }
+}
+
+export function killSosModelRun(sosModelRunName){
+    return function () {
+
+        // make API request, returning a promise
+        return fetch('/api/v1/sos_model_runs/' + sosModelRunName + '/kill', {
+            method: 'post',
+
+            headers: {
+                'Content-Type': 'application/json'
+            }
+        })
+            .then(
+                response => response.json()
             )
     }
 }
@@ -193,14 +256,14 @@ function receiveSosModels(json) {
 
 export function fetchSosModels(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSosModels())
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_models/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSosModels(json))
@@ -226,14 +289,14 @@ function receiveSosModel(json) {
 
 export function fetchSosModel(modelid){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSosModel())
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_models/' + modelid)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSosModel(json))
@@ -242,8 +305,7 @@ export function fetchSosModel(modelid){
 }
 
 export function saveSosModel(model){
-    return function (dispatch) {
-        // inform the app that the API request is starting
+    return function () {
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_models/' + model.name, {
@@ -255,42 +317,28 @@ export function saveSosModel(model){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                //json => dispatch(receiveSosModelRun(json))
+                response => response.json()
             )
     }
 }
 
-export function createSosModel(sosModelName){
+export function createSosModel(sosModel){
     return function (dispatch) {
-        // prepare the new modelrun
-        let datetime = new Date()
-
-        let newModel = {
-            'name': sosModelName,
-            'description': '',
-            'sector_models': [],
-            'dependencies': [],
-            'max_iterations': 1,
-            'convergence_absolute_tolerance': 1e-05,
-            'convergence_relative_tolerance': 1e-05
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/sos_models/', {
             method: 'post',
-            body: JSON.stringify(newModel),
+            body: JSON.stringify(sosModel),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchSosModels())
+                }
             )
     }
 }
@@ -307,8 +355,10 @@ export function deleteSosModel(sosModelName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchSosModels())
+                }
             )
     }
 }
@@ -331,14 +381,14 @@ function receiveSectorModels(json) {
 
 export function fetchSectorModels(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSectorModels())
 
         // make API request, returning a promise
         return fetch('/api/v1/sector_models/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSectorModels(json))
@@ -364,14 +414,14 @@ function receiveSectorModel(json) {
 
 export function fetchSectorModel(modelid){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestSectorModel())
 
         // make API request, returning a promise
         return fetch('/api/v1/sector_models/' + modelid)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveSectorModel(json))
@@ -380,8 +430,7 @@ export function fetchSectorModel(modelid){
 }
 
 export function saveSectorModel(model){
-    return function (dispatch) {
-        // inform the app that the API request is starting
+    return function () {
 
         // make API request, returning a promise
         return fetch('/api/v1/sector_models/' + model.name, {
@@ -393,45 +442,28 @@ export function saveSectorModel(model){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                //json => dispatch(receiveSosModelRun(json))
+                response => response.json()
             )
     }
 }
 
-export function createSectorModel(sectorModelName){
+export function createSectorModel(sectorModel){
     return function (dispatch) {
-        // prepare the new modelrun
-
-        let datetime = new Date()
-
-        let newSectorModel = {
-            'name':  sectorModelName,
-            'description': '',
-            'classname': '',
-            'path': '',
-            'inputs': [],
-            'outputs': [],
-            'parameters': [],
-            'interventions': [],
-            'initial_conditions': []
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/sector_models/', {
             method: 'post',
-            body: JSON.stringify(newSectorModel),
+            body: JSON.stringify(sectorModel),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchSectorModels())
+                }
             )
     }
 }
@@ -448,8 +480,10 @@ export function deleteSectorModel(sectorModelName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchSectorModels())
+                }
             )
     }
 }
@@ -472,14 +506,14 @@ function receiveScenarioSets(json) {
 
 export function fetchScenarioSets(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestScenarioSets())
 
         // make API request, returning a promise
         return fetch('/api/v1/scenario_sets/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveScenarioSets(json))
@@ -505,14 +539,14 @@ function receiveScenarioSet(json) {
 
 export function fetchScenarioSet(scenarioSetName){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestScenarioSet())
 
         // make API request, returning a promise
         return fetch('/api/v1/scenario_sets/' + scenarioSetName)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveScenarioSet(json))
@@ -521,8 +555,7 @@ export function fetchScenarioSet(scenarioSetName){
 }
 
 export function saveScenarioSet(scenarioSet){
-    return function (dispatch) {
-        // inform the app that the API request is starting
+    return function () {
 
         // make API request, returning a promise
         return fetch('/api/v1/scenario_sets/' + scenarioSet.name, {
@@ -534,38 +567,26 @@ export function saveScenarioSet(scenarioSet){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                //json => dispatch(receiveSosModelRun(json))
+                response => response.json()
             )
     }
 }
 
-export function createScenarioSet(scenarioSetName){
+export function createScenarioSet(scenarioSet){
     return function (dispatch) {
-        // prepare the new modelrun
-
-        let datetime = new Date()
-
-        let newScenarioSet = {
-            'name':  scenarioSetName,
-            'description': '',
-        }
-
         // make API request, returning a promise
         return fetch('/api/v1/scenario_sets/', {
             method: 'post',
-            body: JSON.stringify(newScenarioSet),
-
+            body: JSON.stringify(scenarioSet),
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchScenarioSets())
+                }
             )
     }
 }
@@ -582,8 +603,10 @@ export function deleteScenarioSet(scenarioSetName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchScenarioSets())
+                }
             )
     }
 }
@@ -597,6 +620,7 @@ function requestScenarios(){
 
 export const RECEIVE_SCENARIOS = 'RECEIVE_SCENARIOS'
 function receiveScenarios(json) {
+    if (json == null) json = []
     return {
         type: RECEIVE_SCENARIOS,
         scenarios: json,
@@ -606,14 +630,14 @@ function receiveScenarios(json) {
 
 export function fetchScenarios(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestScenarios())
 
         // make API request, returning a promise
         return fetch('/api/v1/scenarios/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveScenarios(json))
@@ -639,14 +663,14 @@ function receiveScenario(json) {
 
 export function fetchScenario(scenarioid){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestScenario())
 
         // make API request, returning a promise
         return fetch('/api/v1/scenarios/' + scenarioid)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveScenario(json))
@@ -656,7 +680,6 @@ export function fetchScenario(scenarioid){
 
 export function saveScenario(scenario){
     return function (dispatch) {
-        // inform the app that the API request is starting
 
         // make API request, returning a promise
         return fetch('/api/v1/scenarios/' + scenario.name, {
@@ -668,36 +691,31 @@ export function saveScenario(scenario){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchScenarios())
+                }
             )
     }
 }
 
-export function createScenario(scenarioName){
+export function createScenario(scenario){
     return function (dispatch) {
-        // prepare the new modelrun
-        let datetime = new Date()
-
-        let newScenario = {
-            'name': scenarioName,
-            'description': '',
-            'scenario_set': '',
-            'parameters': []
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/scenarios/', {
             method: 'post',
-            body: JSON.stringify(newScenario),
+            body: JSON.stringify(scenario),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchScenarios())
+                }
             )
     }
 }
@@ -714,8 +732,10 @@ export function deleteScenario(scenarioName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchScenarios())
+                }
             )
     }
 }
@@ -738,14 +758,14 @@ function receiveNarrativeSets(json) {
 
 export function fetchNarrativeSets(){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestNarrativeSets())
 
         // make API request, returning a promise
         return fetch('/api/v1/narrative_sets/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveNarrativeSets(json))
@@ -771,14 +791,14 @@ function receiveNarrativeSet(json) {
 
 export function fetchNarrativeSet(narrativeSetName){
     return function (dispatch) {
+
         // inform the app that the API request is starting
         dispatch(requestNarrativeSet())
 
         // make API request, returning a promise
         return fetch('/api/v1/narrative_sets/' + narrativeSetName)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveNarrativeSet(json))
@@ -787,8 +807,7 @@ export function fetchNarrativeSet(narrativeSetName){
 }
 
 export function saveNarrativeSet(narrativeSet){
-    return function (dispatch) {
-        // inform the app that the API request is starting
+    return function () {
 
         // make API request, returning a promise
         return fetch('/api/v1/narrative_sets/' + narrativeSet.name, {
@@ -800,38 +819,28 @@ export function saveNarrativeSet(narrativeSet){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
-            )
-            .then(
-                //json => dispatch(receiveSosModelRun(json))
+                response => response.json()
             )
     }
 }
 
-export function createNarrativeSet(narrativeSetName){
+export function createNarrativeSet(narrativeSet){
     return function (dispatch) {
-        // prepare the new modelrun
-
-        let datetime = new Date()
-
-        let newNarrativeSet = {
-            'name':  narrativeSetName,
-            'description': '',
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/narrative_sets/', {
             method: 'post',
-            body: JSON.stringify(newNarrativeSet),
+            body: JSON.stringify(narrativeSet),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchNarrativeSets())
+                }
             )
     }
 }
@@ -848,8 +857,10 @@ export function deleteNarrativeSet(narrativeSetName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchNarrativeSets())
+                }
             )
     }
 }
@@ -878,8 +889,7 @@ export function fetchNarratives(){
         // make API request, returning a promise
         return fetch('/api/v1/narratives/')
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveNarratives(json))
@@ -911,8 +921,7 @@ export function fetchNarrative(narrativeid){
         // make API request, returning a promise
         return fetch('/api/v1/narratives/' + narrativeid)
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
             .then(
                 json => dispatch(receiveNarrative(json))
@@ -921,7 +930,7 @@ export function fetchNarrative(narrativeid){
 }
 
 export function saveNarrative(narrative){
-    return function (dispatch) {
+    return function () {
         // inform the app that the API request is starting
 
         // make API request, returning a promise
@@ -934,36 +943,28 @@ export function saveNarrative(narrative){
             }}
         )
             .then (
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                response => response.json()
             )
     }
 }
 
-export function createNarrative(narrativeName){
+export function createNarrative(narrative){
     return function (dispatch) {
-        // prepare the new modelrun
-        let datetime = new Date()
-
-        let newNarrative = {
-            'name': narrativeName,
-            'description': '',
-            'narrative_set': '',
-            'filename': ''
-        }
 
         // make API request, returning a promise
         return fetch('/api/v1/narratives/', {
             method: 'post',
-            body: JSON.stringify(newNarrative),
+            body: JSON.stringify(narrative),
 
             headers: {
                 'Content-Type': 'application/json'
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchNarratives())
+                }
             )
     }
 }
@@ -980,8 +981,10 @@ export function deleteNarrative(narrativeName){
             }
         })
             .then(
-                response => response.json(),
-                error => console.log('An error occurred.', error)
+                function() {
+                    response => response.json()
+                    dispatch(fetchNarratives())
+                }
             )
     }
 }
