@@ -1,18 +1,18 @@
-import React, { Component } from 'react';
+import React, { Component } from 'react'
 import PropTypes from 'prop-types'
 
-import Modal from 'react-modal';
+import ReactModal from 'react-modal'
 
 const customStyles = {
     content : {
         top                   : '50%',
         left                  : '50%',
-        right                 : 'auto',
+        right                 : '50%',
         bottom                : 'auto',
         marginRight           : '-50%',
         transform             : 'translate(-50%, -50%)'
     }
-};
+}
 
 class Popup extends Component {
     constructor(props) {
@@ -27,30 +27,36 @@ class Popup extends Component {
     }
 
     openCreateSosModelRunPopup() {
-        this.setState({popupIsOpen: true});
+        this.setState({popupIsOpen: true})
     }
 
     closeCreateSosModelRunPopup() {
-        this.setState({popupIsOpen: false});
+        this.setState({popupIsOpen: false})
+    }
+
+    componentDidMount() {
+        ReactModal.setAppElement('body')
     }
 
     render() {
-        const {onRequestOpen, onRequestClose} = this.props
+        const {onRequestOpen, name} = this.props
 
         return (
             <div>
-                <Modal isOpen={onRequestOpen} style={customStyles} contentLabel="Example CreateSosModelRunPopup">
-                    <div>
+                <ReactModal isOpen={onRequestOpen} style={customStyles} contentLabel="Example CreateSosModelRunPopup">
+                    <div id={name}>
                         {this.props.children}
                     </div>
-                </Modal>
+                </ReactModal>
             </div>
         )
     }
 }
 
 Popup.propTypes = {
-    onRequestOpen: PropTypes.bool.isRequired
-};
+    name: PropTypes.string.isRequired,
+    onRequestOpen: PropTypes.bool.isRequired,
+    children: PropTypes.element.isRequired
+}
 
-export default Popup;
+export default Popup
