@@ -1,6 +1,5 @@
 import React, { Component } from 'react'
-import PropTypes, { string } from 'prop-types'
-import update from 'immutability-helper'
+import PropTypes from 'prop-types'
 
 import FaTrash from 'react-icons/lib/fa/trash'
 import FaPencil from 'react-icons/lib/fa/pencil'
@@ -10,33 +9,33 @@ class PropertyList extends Component {
     constructor(props) {
         super(props)
 
-        this.handleChange = this.handleChange.bind(this)
+        this.onEditHandler = this.onEditHandler.bind(this)
+        this.onDeleteHandler = this.onDeleteHandler.bind(this)
 
     }
 
-    handleChange(event) {
+    onEditHandler(event) {
+        const {onEdit} = this.props
+        const target = event.currentTarget
 
-        const {itemsName, items, onChange, onDelete} = this.props
+        onEdit(target.value)
+    }
+
+    onDeleteHandler(event) {
+        const {onDelete} = this.props
 
         const target = event.currentTarget
-        const value = target.type === 'checkbox' ? target.checked : target.value
-        const targetname = target.name
+        const name = target.name
 
-        if (targetname == 'edit') {
-            onChange(value)
-        }
-        else if (targetname == 'delete') {
-            items.splice(value, 1)
-            onDelete(
-                {
-                    target: {
-                        name: itemsName,
-                        value: items,
-                        type: 'array'
-                    }
+        onDelete(
+            {
+                target: {
+                    name: target.value,
+                    value: name,
+                    type: 'action'
                 }
-            )
-        }
+            }
+        )
     }
 
     getColumnSize(columns, editButton, deleteButton, enableWarnings) {
@@ -79,7 +78,7 @@ class PropertyList extends Component {
         if (active) {
             return (
                 <td width='8%' >
-                    <button type="button" className="btn btn-outline-dark" key={itemNumber} value={itemNumber} name='edit' onClick={this.handleChange}>
+                    <button id={'btn_edit_' + itemNumber}  type="button" className="btn btn-outline-dark btn-margin" key={itemNumber} value={itemNumber} name='edit' onClick={this.onEditHandler}>
                         <FaPencil/>
                     </button>
                 </td>
@@ -88,11 +87,11 @@ class PropertyList extends Component {
         return
     }
 
-    getDeleteButton(active, itemNumber) {
+    getDeleteButton(active, itemname, configname) {
         if (active) {
             return (
                 <td width='8%'>
-                    <button type="button" className="btn btn-outline-dark" key={itemNumber} value={itemNumber} name='delete' onClick={this.handleChange}>
+                    <button id={'btn_del_' + configname} type="button" className="btn btn-outline-dark btn-margin" key={itemname} value={itemname} name={configname} onClick={this.onDeleteHandler}>
                         <FaTrash/>
                     </button>
                 </td>
@@ -129,18 +128,17 @@ class PropertyList extends Component {
                         {
                             Object.keys(items).map((item, i) => (
 
-                                <tr id={'property_' + i} key={i}>
+                                <tr id={name + '_property_' + i} key={i}>
                                     {this.getWarning(enableWarnings, item)}
                                     {
                                         Object.keys(columns).map((column, k) => (
                                             <td width={this.getColumnSize(columns, editButton, deleteButton, enableWarnings)} key={k}>
                                                 {items[item][column]}
                                             </td>
-
                                         ))
                                     }
-                                    {this.getEditButton(editButton, item)}
-                                    {this.getDeleteButton(deleteButton, item)}
+                                    {this.getEditButton(editButton, items[item].name)}
+                                    {this.getDeleteButton(deleteButton, name, items[item].name)}
                                 </tr>
                             ))
 
