@@ -2,11 +2,12 @@ import React, { Component } from 'react'
 import PropTypes from 'prop-types'
 import update from 'immutability-helper'
 
+import { SaveButton, CancelButton } from 'components/ConfigForm/General/Buttons'
+
 class NarrativeConfigForm extends Component {
     constructor(props) {
         super(props)
 
-        this.handleKeyPress = this.handleKeyPress.bind(this)
         this.handleChange = this.handleChange.bind(this)
         this.handleSave = this.handleSave.bind(this)
         this.handleCancel = this.handleCancel.bind(this)
@@ -15,20 +16,6 @@ class NarrativeConfigForm extends Component {
         this.state.selectedNarrative = this.props.narrative
     }
 
-    componentDidMount(){
-        document.addEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    componentWillUnmount(){
-        document.removeEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    handleKeyPress(){
-        if(event.keyCode === 27) {
-            this.handleCancel()
-        }
-    }
-
     handleChange(event) {
         const target = event.target
         const value = target.type === 'checkbox' ? target.checked : target.value
@@ -83,8 +70,6 @@ class NarrativeConfigForm extends Component {
                         </div>
                     </div>
 
-                    <br/>
-
                     <div className="card">
                         <div className="card-header">Settings</div>
                         <div className="card-body">
@@ -93,7 +78,7 @@ class NarrativeConfigForm extends Component {
                                 <label className="col-sm-2 col-form-label">Narrative Set</label>
                                 <div className="col-sm-10">
                                     <select className="form-control" name="narrative_set" defaultValue={selectedNarrative.narrative_set} onChange={this.handleChange}>
-                                        <option disabled="disabled" value="" >Please select a Narrative Set</option>
+                                        <option value="" >Please select a Narrative Set</option>
                                         {
                                             narrativeSets.map(narrativeSet =>
                                                 <option key={narrativeSet.name} value={narrativeSet.name}>{narrativeSet.name}</option>
@@ -110,8 +95,6 @@ class NarrativeConfigForm extends Component {
                         </div>
                     </div>
 
-                    <br/>
-
                     <div className="card">
                         <div className="card-header">Parameters</div>
                         <div className="card-body">
@@ -124,15 +107,10 @@ class NarrativeConfigForm extends Component {
                             </div>
                         </div>
                     </div>
-
-                    <br/>
-
                 </form>
 
-                <input id="saveButton" className="btn btn-secondary btn-lg btn-block" type="button" value="Save Sector Model Configuration" onClick={this.handleSave} />
-                <input id="cancelButton" className="btn btn-secondary btn-lg btn-block" type="button" value="Cancel" onClick={this.handleCancel} />
-
-                <br/>
+                <SaveButton id="saveNarrative" onClick={this.handleSave} />
+                <CancelButton id="cancelNarrative" onClick={this.handleCancel} />
             </div>
         )
     }
