@@ -2,11 +2,12 @@ import React, { Component } from 'react'
 import PropTypes from 'prop-types'
 import update from 'immutability-helper'
 
+import { SaveButton, CancelButton } from 'components/ConfigForm/General/Buttons'
+
 class NarrativeSetConfigForm extends Component {
     constructor(props) {
         super(props)
 
-        this.handleKeyPress = this.handleKeyPress.bind(this)
         this.handleChange = this.handleChange.bind(this)
         this.handleSave = this.handleSave.bind(this)
         this.handleCancel = this.handleCancel.bind(this)
@@ -15,20 +16,6 @@ class NarrativeSetConfigForm extends Component {
         this.state.selectedNarrativeSet = this.props.narrativeSet
     }
 
-    componentDidMount(){
-        document.addEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    componentWillUnmount(){
-        document.removeEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    handleKeyPress(){
-        if(event.keyCode === 27) {
-            this.handleCancel()
-        }
-    }
-
     handleChange(event) {
         const target = event.target
         const value = target.type === 'checkbox' ? target.checked : target.value
@@ -73,15 +60,10 @@ class NarrativeSetConfigForm extends Component {
 
                         </div>
                     </div>
-
-                    <br/>
-
                 </form>
 
-                <input id="saveButton" className="btn btn-secondary btn-lg btn-block" type="button" value="Save Narrative Set Configuration" onClick={this.handleSave} />
-                <input id="cancelButton" className="btn btn-secondary btn-lg btn-block" type="button" value="Cancel" onClick={this.handleCancel} />
-
-                <br/>
+                <SaveButton id="saveNarrativeSet" onClick={this.handleSave} />
+                <CancelButton id="cancelNarrativeSet" onClick={this.handleCancel} />
             </div>
         )
     }
