@@ -1,40 +1,37 @@
 import React, { Component } from 'react'
-import PropTypes, { object } from 'prop-types'
+import PropTypes from 'prop-types'
 import update from 'immutability-helper'
 
-import PropertySelector from './General/PropertySelector.js'
-import DependencySelector from './SosModel/DependencySelector.js'
-import PropertyList from './General/PropertyList.js'
+import Popup from 'components/ConfigForm/General/Popup.js'
+import PropertySelector from 'components/ConfigForm/General/PropertySelector.js'
+import DependencySelector from 'components/ConfigForm/SosModel/DependencySelector.js'
+import PropertyList from 'components/ConfigForm/General/PropertyList.js'
+import DeleteForm from 'components/ConfigForm/General/DeleteForm.js'
+import { SaveButton, CancelButton } from 'components/ConfigForm/General/Buttons'
 
 class SosModelConfigForm extends Component {
     constructor(props) {
         super(props)
 
-        this.handleKeyPress = this.handleKeyPress.bind(this)
         this.handleChange = this.handleChange.bind(this)
         this.handleSave = this.handleSave.bind(this)
         this.handleCancel = this.handleCancel.bind(this)
 
-        this.state = {}
-        this.state.selectedSosModel = this.props.sosModel
-        this.state.dependencyWarning = []
+        this.state = {
+            selectedSosModel: this.props.sosModel,
+            dependencyWarning: [],
+            deletePopupIsOpen: false
+        }
+
+        this.closeDeletePopup = this.closeDeletePopup.bind(this)
+        this.openDeletePopup = this.openDeletePopup.bind(this)
+        this.handleDelete = this.handleDelete.bind(this)
     }
 
     componentDidMount(){
-        document.addEventListener("keydown", this.handleKeyPress, false)
         this.validateForm()
     }
 
-    componentWillUnmount(){
-        document.removeEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    handleKeyPress(){
-        if(event.keyCode === 27) {
-            this.handleCancel()
-        }
-    }
-
     handleChange(event) {
         const target = event.target
         const value = target.type === 'checkbox' ? target.checked : target.value
@@ -47,6 +44,17 @@ class SosModelConfigForm extends Component {
         })
     }
 
+    handleDelete(config) {
+        const {deletePopupType} = this.state
+
+        switch(deletePopupType) {
+        case 'dependency':
+            this.state.selectedSosModel.dependencies.splice(config, 1)
+        }
+
+        this.closeDeletePopup()
+    }
+
     validateForm() {
         const {selectedSosModel} = this.state
 
@@ -68,7 +76,7 @@ class SosModelConfigForm extends Component {
                 dependencyWarning: illegalDependencies
             })
         }
-        
+
     }
 
     handleSave() {
@@ -79,10 +87,36 @@ class SosModelConfigForm extends Component {
         this.props.cancelSosModel()
     }
 
+    openDeletePopup(event) {
+        this.setState({
+            deletePopupIsOpen: true,
+            deletePopupConfigName: event.target.value,
+            deletePopupType: event.target.name,
+        })
+    }
+
+    closeDeletePopup() {
+        this.setState({deletePopupIsOpen: false})
+    }
+
     render() {
         const {sectorModels, scenarioSets, narrativeSets} = this.props
         const {selectedSosModel} = this.state
 
+        // Get dependencies, give an index as name
+        let dependencies = []
+        if (selectedSosModel.dependencies != undefined) {
+            for (let i = 0; i < selectedSosModel.dependencies.length; i++) {
+                dependencies.push({
+                    name: i,
+                    sink_model: selectedSosModel.dependencies[i].sink_model,
+                    sink_model_input: selectedSosModel.dependencies[i].sink_model_input,
+                    source_model: selectedSosModel.dependencies[i].source_model,
+                    source_model_output: selectedSosModel.dependencies[i].source_model_output
+                })
+            }
+        }
+
         return (
             <div>
                 <form>
@@ -107,8 +141,6 @@ class SosModelConfigForm extends Component {
                         </div>
                     </div>
 
-                    <br/>
-
                     <div className="card">
                         <div className="card-header">Settings</div>
                         <div className="card-body">
@@ -136,18 +168,14 @@ class SosModelConfigForm extends Component {
                         </div>
                     </div>
 
-                    <br/>
-
                     <div className="card">
                         <div className="card-header">Dependencies</div>
                         <div className="card-body">
-                            <PropertyList itemsName="dependencies" items={selectedSosModel.dependencies} columns={{source_model: 'Source', source_model_output: 'Output', sink_model: 'Sink', sink_model_input: 'Input'}} enableWarnings={true} rowWarning={this.state.dependencyWarning} editButton={false} deleteButton={true} onDelete={this.handleChange} />
-                            <DependencySelector dependencies={selectedSosModel.dependencies} sectorModels={selectedSosModel.sector_models} scenarioSets={selectedSosModel.scenario_sets} onChange={this.handleChange}/>
+                            <PropertyList itemsName="dependency" items={dependencies} columns={{source_model: 'Source', source_model_output: 'Output', sink_model: 'Sink', sink_model_input: 'Input'}} enableWarnings={true} rowWarning={this.state.dependencyWarning} editButton={false} deleteButton={true} onDelete={this.openDeletePopup} />
+                            <DependencySelector sectorModels={sectorModels} scenarioSets={scenarioSets} dependencies={selectedSosModel.dependencies} selectedSectorModels={selectedSosModel.sector_models} selectedScenarioSets={selectedSosModel.scenario_sets} onChange={this.handleChange}/>
                         </div>
                     </div>
 
-                    <br/>
-
                     <div className="card">
                         <div className="card-header">Iteration Settings</div>
                         <div className="card-body">
@@ -172,12 +200,14 @@ class SosModelConfigForm extends Component {
                             </div>
                         </div>
                     </div>
-
-                    <br/>
                 </form>
 
-                <input className="btn btn-secondary btn-lg btn-block" type="button" value="Save System-of-systems Model Configuration" onClick={this.handleSave} />
-                <input className="btn btn-secondary btn-lg btn-block" type="button" value="Cancel" onClick={this.handleCancel} />
+                <Popup name='popup_dependency_selector' onRequestOpen={this.state.deletePopupIsOpen}>
+                    <DeleteForm config_name={this.state.deletePopupConfigName} config_type={this.state.deletePopupType} submit={this.handleDelete} cancel={this.closeDeletePopup}/>
+                </Popup>
+
+                <SaveButton onClick={this.handleSave} />
+                <CancelButton onClick={this.handleCancel} />
 
                 <br/>
             </div>
