@@ -2,16 +2,16 @@ import React, { Component } from 'react'
 import PropTypes from 'prop-types'
 import update from 'immutability-helper'
 
-import SosModelSelector from './SosModelRun/SosModelSelector.js'
-import ScenarioSelector from './SosModelRun/ScenarioSelector.js'
-import NarrativeSelector from './SosModelRun/NarrativeSelector.js'
-import TimestepSelector from './SosModelRun/TimestepSelector.js'
+import SosModelSelector from 'components/ConfigForm/SosModelRun/SosModelSelector.js'
+import ScenarioSelector from 'components/ConfigForm/SosModelRun/ScenarioSelector.js'
+import NarrativeSelector from 'components/ConfigForm/SosModelRun/NarrativeSelector.js'
+import TimestepSelector from 'components/ConfigForm/SosModelRun/TimestepSelector.js'
+import { SaveButton, CancelButton } from 'components/ConfigForm/General/Buttons'
 
 class SosModelRunConfigForm extends Component {
     constructor(props) {
         super(props)
 
-        this.handleKeyPress = this.handleKeyPress.bind(this)
         this.handleSosModelChange = this.handleSosModelChange.bind(this)
         this.handleScenariosChange = this.handleScenariosChange.bind(this)
         this.handleNarrativeChange = this.handleNarrativeChange.bind(this)
@@ -24,20 +24,6 @@ class SosModelRunConfigForm extends Component {
         this.state.selectedSosModelRun = this.props.sosModelRun
     }
 
-    componentDidMount(){
-        document.addEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    componentWillUnmount(){
-        document.removeEventListener("keydown", this.handleKeyPress, false)
-    }
-
-    handleKeyPress(){
-        if(event.keyCode === 27) {
-            this.handleCancel()
-        }
-    }
-
     handleSosModelChange(sos_model) {
         this.setState({
             selectedSosModelRun: update(this.state.selectedSosModelRun, {sos_model: {$set: sos_model}})
@@ -57,7 +43,13 @@ class SosModelRunConfigForm extends Component {
      */
         const { scenarios } = this.state.selectedSosModelRun
 
-        scenarios[scenario_set] = scenario
+        if (scenario == '') {
+            delete scenarios[scenario_set]
+        } else {
+            scenarios[scenario_set] = scenario
+        }
+
+        this.forceUpdate()
     }
 
     handleNarrativeChange(narrative_set, narrative, active) {
@@ -73,8 +65,6 @@ class SosModelRunConfigForm extends Component {
      * active:
      *     The new state of this narrative
      */
-        const {narratives} = this.state.selectedSosModelRun
-
         let obj = this.state.selectedSosModelRun.narratives
 
         if (active) {
@@ -154,8 +144,6 @@ class SosModelRunConfigForm extends Component {
                     </div>
                 </div>
 
-                <br/>
-
                 <div className="card">
                     <div className="card-header">Model</div>
                     <div className="card-body">
@@ -170,8 +158,6 @@ class SosModelRunConfigForm extends Component {
                     </div>
                 </div>
 
-                <br/>
-
                 <div className="card">
                     <div className="card-header">Settings</div>
                     <div className="card-body">
@@ -192,8 +178,6 @@ class SosModelRunConfigForm extends Component {
                     </div>
                 </div>
 
-                <br/>
-
                 <div className="card">
                     <div className="card-header">Timesteps</div>
                     <div className="card-body">
@@ -201,12 +185,8 @@ class SosModelRunConfigForm extends Component {
                     </div>
                 </div>
 
-                <br/>
-
-                <input className="btn btn-secondary btn-lg btn-block" type="button" value="Save Model Run Configuration" onClick={this.handleSave} />
-                <input className="btn btn-secondary btn-lg btn-block" type="button" value="Cancel" onClick={this.handleCancel} />
-
-                <br/>
+                <SaveButton onClick={this.handleSave} />
+                <CancelButton onClick={this.handleCancel} />
             </div>
         )
     }
