@@ -6,6 +6,8 @@ import {
     RECEIVE_SOS_MODEL_RUNS,
     REQUEST_SOS_MODEL_RUN,
     RECEIVE_SOS_MODEL_RUN,
+    REQUEST_SOS_MODEL_RUN_STATUS,
+    RECEIVE_SOS_MODEL_RUN_STATUS,
     REQUEST_SOS_MODELS,
     RECEIVE_SOS_MODELS,
     REQUEST_SOS_MODEL,
@@ -34,7 +36,7 @@ import {
 
 function smif(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -80,7 +82,7 @@ function sos_model_runs(
 
 function sos_model_run(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -101,9 +103,32 @@ function sos_model_run(
     }
 }
 
+function sos_model_run_status(
+    state = {
+        isFetching: true,
+        item: {}
+    },
+    action
+) {
+    switch (action.type){
+    case REQUEST_SOS_MODEL_RUN_STATUS:
+        return Object.assign({}, state, {
+            isFetching: true
+        })
+    case RECEIVE_SOS_MODEL_RUN_STATUS:
+        return Object.assign({}, state, {
+            isFetching: false,
+            item: action.sos_model_run_status,
+            lastUpdated: action.receivedAt
+        })
+    default:
+        return state
+    }
+}
+
 function sos_models(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -126,7 +151,7 @@ function sos_models(
 
 function sos_model(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -149,7 +174,7 @@ function sos_model(
 
 function sector_models(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -172,7 +197,7 @@ function sector_models(
 
 function sector_model(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -195,7 +220,7 @@ function sector_model(
 
 function scenario_sets(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -218,7 +243,7 @@ function scenario_sets(
 
 function scenario_set(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -241,7 +266,7 @@ function scenario_set(
 
 function scenarios(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -264,7 +289,7 @@ function scenarios(
 
 function scenario(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -287,7 +312,7 @@ function scenario(
 
 function narrative_sets(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -310,7 +335,7 @@ function narrative_sets(
 
 function narrative_set(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -333,7 +358,7 @@ function narrative_set(
 
 function narratives(
     state = {
-        isFetching: false,
+        isFetching: true,
         items: []
     },
     action
@@ -356,7 +381,7 @@ function narratives(
 
 function narrative(
     state = {
-        isFetching: false,
+        isFetching: true,
         item: {}
     },
     action
@@ -381,6 +406,7 @@ const rootReducer = combineReducers({
     smif,
     sos_model_runs,
     sos_model_run,
+    sos_model_run_status,
     sos_models,
     sos_model,
     sector_models,
