@@ -1,11 +1,13 @@
 import React from 'react'
 import { expect } from 'chai'
-import { shallow } from 'enzyme'
+import { render } from 'enzyme'
+import { describe, it } from 'mocha'
+
 import Welcome from '../../src/components/Welcome.js'
 
 describe('<Welcome />', () => {
     it('renders heading text', () => {
-        const wrapper = shallow(<Welcome />)
+        const wrapper = render(<Welcome />)
         expect(wrapper.find('h1').text()).to.contain('Welcome')
     })
 })
