@@ -6,11 +6,9 @@
 #         from smif.data_layer import DatabaseInterface`
 from smif.data_layer.database_interface import DatabaseInterface
 from smif.data_layer.datafile_interface import DatafileInterface
-from smif.data_layer.data_interface import (
-    DataExistsError,
-    DataMismatchError,
-    DataNotFoundError
-)
+from smif.data_layer.data_interface import (DataExistsError, DataMismatchError,
+                                            DataNotFoundError)
+
 from smif.data_layer.data_handle import DataHandle
 from smif.data_layer.memory_interface import MemoryInterface
 
