@@ -7,19 +7,20 @@ data (at any computed or pre-computed timestep) and write access to output data
 (at the current timestep).
 """
 
-from logging import getLogger
-
 from enum import Enum
-from smif.model.scenario_model import ScenarioModel
+from logging import getLogger
 from types import MappingProxyType
 
+from smif.model.scenario_model import ScenarioModel
+
 
 class DataHandle(object):
     """Get/set model parameters and data
     """
     def __init__(self, store, modelrun_name, current_timestep, timesteps, model,
                  modelset_iteration=None, decision_iteration=None):
-        """Create a DataHandle for a Model to
+        """Create a DataHandle for a Model to access data, parameters and state, and to
+        communicate results.
 
         Parameters
         ----------
@@ -29,10 +30,11 @@ class DataHandle(object):
             Name of the current modelrun
         model : Model
             Model which will use this DataHandle
-        modelset_iteration :
+        modelset_iteration : int, default=None
             ID of the current ModelSet iteration
-        decision_iteration :
+        decision_iteration : int, default=None
             ID of the current Decision iteration
+        state : list, default=None
         """
         self.logger = getLogger(__name__)
         self._store = store
@@ -46,11 +48,30 @@ class DataHandle(object):
         self._inputs = model.inputs
         self._outputs = model.outputs
         self._dependencies = model.deps
+        self._model = model
 
         configured_parameters = self._store.read_parameters(
             self._modelrun_name, self._model_name)
         self._parameters = model.parameters.overridden(configured_parameters)
 
+    def derive_for(self, model):
+        """Derive a new DataHandle configured for the given Model
+
+        Parameters
+        ----------
+        model : Model
+            Model which will use this DataHandle
+        """
+        return DataHandle(
+            store=self._store,
+            modelrun_name=self._modelrun_name,
+            current_timestep=self._current_timestep,
+            timesteps=list(self.timesteps),
+            model=model,
+            modelset_iteration=self._modelset_iteration,
+            decision_iteration=self._decision_iteration
+        )
+
     def __getitem__(self, key):
         if key in self._parameters:
             return self.get_parameter(key)
@@ -95,6 +116,25 @@ class DataHandle(object):
         """
         return tuple(self._timesteps)
 
+    def get_state(self):
+        """The current state of the model
+
+        Returns
+        -------
+        A list of interventions installed at the current timestep
+        """
+        if self._current_timestep is None:
+            raise ValueError("Cannot get state when timestep is None")
+        sos_state = self._store.read_state(
+            self._modelrun_name,
+            self._current_timestep,
+            self._decision_iteration
+        )
+        # here could (should?) filter list for interventions applicable to a model
+        # and look up full intervention (not just name,build_year)
+
+        return sos_state
+
     def get_data(self, input_name, timestep=None):
         """Get data required for model inputs
 
@@ -184,6 +224,12 @@ class DataHandle(object):
         """
         return self.get_data(input_name, RelativeTimestep.PREVIOUS)
 
+    def get_region_names(self, spatial_resolution):
+        return self._store.read_region_names(spatial_resolution)
+
+    def get_interval_names(self, temporal_resolution):
+        return self._store.read_interval_names(temporal_resolution)
+
     def get_parameter(self, parameter_name):
         """Get the value for a  parameter
 
@@ -228,6 +274,19 @@ class DataHandle(object):
             "Write %s %s %s %s", self._model_name, output_name, self._current_timestep,
             self._modelset_iteration)
 
+        num_regions = len(self._outputs[output_name].spatial_resolution)
+        num_intervals = len(self._outputs[output_name].temporal_resolution)
+        expected_shape = (num_regions, num_intervals)
+        if data.shape != expected_shape:
+            raise ValueError(
+                "Tried to set results with shape {}, expected {} for {}:{}".format(
+                    data.shape,
+                    expected_shape,
+                    self._model_name,
+                    output_name
+                )
+            )
+
         self._store.write_results(
             self._modelrun_name,
             self._model_name,
@@ -327,6 +386,12 @@ class TimestepResolutionError(Exception):
     pass
 
 
+class DataError(Exception):
+    """Raise on attempts at invalid data access (get/set)
+    """
+    pass
+
+
 def element_before(element, list_):
     """Return the element before a given element in a list, or None if the
     given element is first or not in the list.
