@@ -1,12 +1,7 @@
 # -*- coding: utf-8 -*-
 """Parse yaml config files, to construct sector models
 """
-import yaml
-
-try:
-    from yaml import CLoader as Loader, CDumper as Dumper
-except ImportError:
-    from yaml import Loader, Dumper
+from ruamel.yaml import YAML
 
 
 def load(file_path):
@@ -18,7 +13,7 @@ def load(file_path):
         The path of the configuration file to parse
     """
     with open(file_path, 'r') as file_handle:
-        return yaml.load(file_handle, Loader=Loader)
+        return YAML().load(file_handle)
 
 
 def dump(data, file_path):
@@ -26,11 +21,13 @@ def dump(data, file_path):
 
     Parameters
     ----------
-    file_path : str
-        The path of the configuration file to write
     data
         Data to write (should be lists, dicts and simple values)
+    file_path : str
+        The path of the configuration file to write
     """
     with open(file_path, 'w') as file_handle:
-        return yaml.dump(data, file_handle, Dumper=Dumper,
-                         default_flow_style=False, allow_unicode=True)
+        yaml = YAML()
+        yaml.default_flow_style = False
+        yaml.allow_unicode = True
+        return yaml.dump(data, file_handle)
