@@ -34,8 +34,6 @@ A more comprehensive example with one scenario and one scenario model:
 >>> class EnergyModel(SectorModel):
 ...   def extract_obj(self):
 ...     pass
-...   def initialise(self):
-...     pass
 ...   def simulate(self, timestep, data):
 ...     return {self.name: {'cost': data['input'] * 2}}
 ...
@@ -54,6 +52,7 @@ from logging import getLogger
 
 from smif.convert.area import get_register as get_region_register
 from smif.convert.interval import get_register as get_interval_register
+from smif.convert.unit import get_register as get_unit_register
 from smif.metadata import MetadataSet
 from smif.model.dependency import Dependency
 from smif.parameters import ParameterList
@@ -70,6 +69,9 @@ class Model(metaclass=ABCMeta):
     outputs : smif.metadata.MetaDataSet
 
     """
+    regions = get_region_register()
+    intervals = get_interval_register()
+    units = get_unit_register()
 
     def __init__(self, name):
         self.name = name
@@ -80,8 +82,6 @@ class Model(metaclass=ABCMeta):
 
         self._parameters = ParameterList()
 
-        self.regions = get_region_register()
-        self.intervals = get_interval_register()
         self.timesteps = []
 
         self.logger = getLogger(__name__)
